      SUBROUTINE DELAZ(SLAT, SLON, DEKM, DEDEG, AZ0, EQLAT, EQLON)
C
C-------- DELAZ - CALCULATE THE DISTANCE IN KM (APPROX EQUAL TO GEOCENTRIC
C      DISTANCE TIMES LOCAL RADIUS), AND AZIMUTHS IN RADIANS
C
C INPUT:  SLAT     STATION GEOCENTRIC LATITUDE IN RADIANS
C         SLON     STATION LONGITUDE IN RADIANS
C         EQLAT    EARTHQUAKE GEOCENTRIC LATITUDE IN RADIANS
C         EQLON    EARTHQUAKE LONGITUDE IN RADIANS
C OUTPUT: DEKM     DISTANCE FROM EARTHQUAKE TO STATION IN KILOMETERS
C         DEDEG    DISTANCE FROM EARTHQAUKE TO STATION IN DEGREES
C         AZ0      AZIMUTH FROM EARTHQUAKE TO STATION MEASURED CLOCKWISE
C                     FROM NORTH IN DEGREES
C
      PARAMETER (PI = 3.14159265)
      PARAMETER (TWOPI = 2.0*PI)
      PARAMETER (HALFPI = 0.5*PI)
      PARAMETER (RAD = PI/180.)
      PARAMETER (DEG = 1.0/RAD)
      PARAMETER (EQURAD = 6378.2064)
      PARAMETER (POLRAD = 6356.5838)
      PARAMETER (FLAT = (EQURAD - POLRAD)/EQURAD)
C
      ST0 = COS(EQLAT)
      CT0 = SIN(EQLAT)
C USE APPROXIMATION OF LOCAL RADIUS FOR DERIVATIVE OF SURFACE
C     DISTANCE WITH GEOCENTRIC LATITUDE.
C  MORE ACCURATE FORMULATION WOULD BE:
C      DRDTH = -R**3 * COS(SLAT)*SIN(SLAT)*( (1.-FLAT)**(-2) - 1. )/A**2
C      DSD = SQRT(DRDTH**2 + R**2)
      RADIUS = (COS(EQLAT)**2/EQURAD**2 +
     *SIN(EQLAT)**2/POLRAD**2)**(-.5)
      CT1 = SIN(SLAT)
      ST1 = COS(SLAT)
      SDLON = SIN(EQLON-SLON)
      CDLON = COS(EQLON-SLON)
      CDELT = ST0*ST1*CDLON+CT0*CT1
      CALL CVRTOP(ST0*CT1-ST1*CT0*CDLON, ST1*SDLON, SDELT, AZ0)
      DEDEG = ATAN2(SDELT, CDELT)*DEG
      DEKM = RADIUS*ATAN2(SDELT, CDELT)
      IF (AZ0 .LT. 0.0) AZ0 = AZ0 + TWOPI
      IF (AZ0 .GE. TWOPI) AZ0 = AZ0 - TWOPI
      AZ0 = 360.-AZ0*DEG
C CALCULATION OF BACK AZIMUTH IF NEEDED
C      CALL CVRTOP(ST1*CT0 - ST0*CT1*CDLON, (-SDLON)*ST0, SDELT, AZ1)
C      IF (AZ1 .LT. 0.0) AZ1 = AZ1 + TWOPI
      RETURN
      END
